# History

## 0.1.1 (2023-04-07)
- Update readme to work on PyPI.
- Make user input prompt clearer.
- Fix: add missing dependencies

## 0.1.0 (2023-04-07)
- First release on PyPI.
- Simple minimum viable product with core plotting functionality.